adapter

package
v0.0.0-...-d6fd5ef Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2017 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Inventory

func Inventory() []adapter.RegisterFn

Inventory returns the inventory of all available adapters.

Types

This section is empty.

Directories

Path Synopsis
Package kubernetes provides functionality to adapt mixer behavior to the kubernetes environment.
Package kubernetes provides functionality to adapt mixer behavior to the kubernetes environment.
Package memQuota provides a simple in-memory quota implementation.
Package memQuota provides a simple in-memory quota implementation.
Package noop is an empty adapter implementing every aspect.
Package noop is an empty adapter implementing every aspect.
Package prometheus publishes metric values collected by Mixer for ingestion by prometheus.
Package prometheus publishes metric values collected by Mixer for ingestion by prometheus.
Package redisquota provides a quota implementation with redis as backend.
Package redisquota provides a quota implementation with redis as backend.
Package stdioLogger provides an implementation of Mixer's logger aspect that writes logs (serialized as JSON) to a standard stream (stdout | stderr).
Package stdioLogger provides an implementation of Mixer's logger aspect that writes logs (serialized as JSON) to a standard stream (stdout | stderr).

Jump to